'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.feathersWrapperDefaultProps = exports.feathersWrapperPropTypes = undefined;

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// from socket-io-client library
var socketioOptionsShape = {
  /**
   * Should we force a new Manager for this connection?
   * @default false
   */
  forceNew: _propTypes2.default.bool,

  /**
   * Should we multiplex our connection (reuse existing Manager) ?
   * @default true
   */
  multiplex: _propTypes2.default.bool,

  /**
   * The path to get our client file from, in the case of the server
   * serving it
   * @default '/socket.io'
   */
  path: _propTypes2.default.string,

  /**
   * Should we allow reconnections?
   * @default true
   */
  reconnection: _propTypes2.default.bool,

  /**
   * How many reconnection attempts should we try?
   * @default Infinity
   */
  reconnectionAttempts: _propTypes2.default.number,

  /**
   * The time delay in milliseconds between reconnection attempts
   * @default 1000
   */
  reconnectionDelay: _propTypes2.default.number,

  /**
   * The max time delay in milliseconds between reconnection attempts
   * @default 5000
   */
  reconnectionDelayMax: _propTypes2.default.bool,

  /**
   * Used in the exponential backoff jitter when reconnecting
   * @default 0.5
   */
  randomizationFactor: _propTypes2.default.number,

  /**
   * The timeout in milliseconds for our connection attempt
   * @default 20000
   */
  timeout: _propTypes2.default.number,

  /**
   * Should we automically connect?
   * @default true
   */
  autoConnect: _propTypes2.default.bool,

  /**
   * The host that we're connecting to. Set from the URI passed when connecting
   */
  host: _propTypes2.default.string,

  /**
   * The hostname for our connection. Set from the URI passed when connecting
   */
  hostname: _propTypes2.default.string,

  /**
   * If this is a secure connection. Set from the URI passed when connecting
   */
  secure: _propTypes2.default.bool,

  /**
   * The port for our connection. Set from the URI passed when connecting
   */
  port: _propTypes2.default.string,

  /**
   * Any query parameters in our uri. Set from the URI passed when connecting
   */
  query: _propTypes2.default.object,

  /**
   * `http.Agent` to use, defaults to `false` (NodeJS only)
   */
  agent: _propTypes2.default.oneOfType([_propTypes2.default.bool, _propTypes2.default.string]),

  /**
   * Whether the client should try to upgrade the transport from
   * long-polling to something better.
   * @default true
   */
  upgrade: _propTypes2.default.bool,

  /**
   * Forces JSONP for polling transport.
   */
  forceJSONP: _propTypes2.default.bool,

  /**
   * Determines whether to use JSONP when necessary for polling. If
   * disabled (by settings to false) an error will be emitted (saying
   * "No transports available") if no other transports are available.
   * If another transport is available for opening a connection (e.g.
   * WebSocket) that transport will be used instead.
   * @default true
   */
  jsonp: _propTypes2.default.bool,

  /**
   * Forces base 64 encoding for polling transport even when XHR2
   * responseType is available and WebSocket even if the used standard
   * supports binary.
   */
  forceBase64: _propTypes2.default.bool,

  /**
   * Enables XDomainRequest for IE8 to avoid loading bar flashing with
   * click sound. default to `false` because XDomainRequest has a flaw
   * of not sending cookie.
   * @default false
   */
  enablesXDR: _propTypes2.default.bool,

  /**
   * The param name to use as our timestamp key
   * @default 't'
   */
  timestampParam: _propTypes2.default.string,

  /**
   * Whether to add the timestamp with each transport request. Note: this
   * is ignored if the browser is IE or Android, in which case requests
   * are always stamped
   * @default false
   */
  timestampRequests: _propTypes2.default.bool,

  /**
   * A list of transports to try (in order). Engine.io always attempts to
   * connect directly with the first one, provided the feature detection test
   * for it passes.
   * @default ['polling','websocket']
   */
  transports: _propTypes2.default.arrayOf(_propTypes2.default.string),

  /**
   * The port the policy server listens on
   * @default 843
   */
  policyPost: _propTypes2.default.number,

  /**
   * If true and if the previous websocket connection to the server succeeded,
   * the connection attempt will bypass the normal upgrade process and will
   * initially try websocket. A connection attempt following a transport error
   * will use the normal upgrade process. It is recommended you turn this on
   * only when using SSL/TLS connections, or if you know that your network does
   * not block websockets.
   * @default false
   */
  rememberUpgrade: _propTypes2.default.bool,

  /**
   * Are we only interested in transports that support binary?
   */
  onlyBinaryUpgrades: _propTypes2.default.bool,

  /**
   * Transport options for Node.js client (headers etc)
   */
  transportOptions: _propTypes2.default.object,

  /**
   * (SSL) Certificate, Private key and CA certificates to use for SSL.
   * Can be used in Node.js client environment to manually specify
   * certificate information.
   */
  pfx: _propTypes2.default.string,

  /**
   * (SSL) Private key to use for SSL. Can be used in Node.js client
   * environment to manually specify certificate information.
   */
  key: _propTypes2.default.string,

  /**
   * (SSL) A string or passphrase for the private key or pfx. Can be
   * used in Node.js client environment to manually specify certificate
   * information.
   */
  passphrase: _propTypes2.default.string,

  /**
   * (SSL) Public x509 certificate to use. Can be used in Node.js client
   * environment to manually specify certificate information.
   */
  cert: _propTypes2.default.string,

  /**
   * (SSL) An authority certificate or array of authority certificates to
   * check the remote host against.. Can be used in Node.js client
   * environment to manually specify certificate information.
   */
  ca: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.arrayOf(_propTypes2.default.string)]),

  /**
   * (SSL) A string describing the ciphers to use or exclude. Consult the
   * [cipher format list]
   * (http://www.openssl.org/docs/apps/ciphers.html#CIPHER_LIST_FORMAT) for
   * details on the format.. Can be used in Node.js client environment to
   * manually specify certificate information.
   */
  ciphers: _propTypes2.default.string,

  /**
   * (SSL) If true, the server certificate is verified against the list of
   * supplied CAs. An 'error' event is emitted if verification fails.
   * Verification happens at the connection level, before the HTTP request
   * is sent. Can be used in Node.js client environment to manually specify
   * certificate information.
   */
  rejectUnauthorized: _propTypes2.default.bool
};

var connectionCallbacksShape = {
  connect: _propTypes2.default.func,
  disconnect: _propTypes2.default.func,
  reconnect: _propTypes2.default.func,
  reconnecting: _propTypes2.default.func,
  reconnect_error: _propTypes2.default.func,
  reconnect_failed: _propTypes2.default.func
};

var feathersSocketioOptionsShape = {
  events: _propTypes2.default.arrayOf(_propTypes2.default.func),
  name: _propTypes2.default.string,
  connection: _propTypes2.default.object,
  method: _propTypes2.default.string,
  timeout: _propTypes2.default.number
};

var feathersAuthOptionsShape = {
  header: _propTypes2.default.string,
  cookie: _propTypes2.default.string,
  storageKey: _propTypes2.default.string,
  jwtStrategy: _propTypes2.default.string,
  path: _propTypes2.default.string,
  entity: _propTypes2.default.string,
  service: _propTypes2.default.string,
  timeout: _propTypes2.default.number
};

var feathersWrapperPropTypes = exports.feathersWrapperPropTypes = {
  children: _propTypes2.default.node.isRequired,
  wsEndpoint: _propTypes2.default.string.isRequired,
  loader: _propTypes2.default.node,
  socketioOptions: _propTypes2.default.shape(socketioOptionsShape),
  connectionCallbacks: _propTypes2.default.shape(connectionCallbacksShape),
  feathersSocketioOptions: _propTypes2.default.shape(feathersSocketioOptionsShape),
  feathersAuthOptions: _propTypes2.default.shape(feathersAuthOptionsShape),
  idField: _propTypes2.default.string
};

var feathersWrapperDefaultProps = exports.feathersWrapperDefaultProps = {
  wsEndpoint: 'http://127.0.0.1:3030',
  loader: null,
  socketioOptions: {},
  feathersSocketioOptions: {
    timeout: 500
  },
  connectionCallbacks: {},
  // default props found in the package
  authOptionsShape: {},
  idField: "id"
};